@@ -52,7 +52,7 @@ impl<T: PartialOrd + Clone> MinMax<T> {
 
     /// Returns true if there are no data points.
     pub fn is_empty(&self) -> bool {
-        self.len != 0
+        self.len == 0
     }
 }
 
@@ -117,6 +117,12 @@ mod test {
         assert_eq!(minmax.min(), Some(&1u32));
         assert_eq!(minmax.max(), Some(&10u32));
     }
+    
+    #[test]
+    fn minmax_empty() {
+        let minmax: MinMax<u32> = MinMax::new();
+        assert_eq!(minmax.is_empty(), true);
+    }
 
     #[test]
     fn minmax_merge_empty() {
