@@ -93,6 +93,11 @@ impl OnlineStats {
     pub fn len(&self) -> usize {
         self.size as usize
     }
+
+    /// Returns if empty.
+    pub fn is_empty(&self) -> bool {
+        self.size == 0
+    }
 }
 
 impl Commute for OnlineStats {
@@ -156,6 +161,12 @@ mod test {
         assert_eq!(expected.stddev(), got.stddev());
     }
 
+    #[test]
+    fn stddev_empty() {
+        let expected = OnlineStats::new();
+        assert_eq!(expected.is_empty(), true);
+    }
+
     #[test]
     fn stddev_many() {
         // TODO: Convert this to a quickcheck test.
